@@ -10,6 +10,34 @@ jomo1rancon.MCMCchain<- function(Y, X=NULL, Z=NULL, clus, beta.start=NULL, u.sta
   if (is.null(u.start)) u.start = matrix(0, nlevels(clus), ncol(Z)*ncol(Y))
   if (is.null(l2cov.start)) l2cov.start = diag(1, ncol(u.start))
   if (is.null(l2cov.prior)) l2cov.prior = diag(1, ncol(l2cov.start))
+  if (any(is.na(Y))) {
+    if (ncol(Y)==1) {
+      miss.pat<-matrix(c(0,1),2,1)
+      n.patterns<-2
+    } else  {
+      miss.pat<-md.pattern.mice(Y, plot=F)
+      miss.pat<-miss.pat[,colnames(Y)]
+      n.patterns<-nrow(miss.pat)-1
+    }
+  } else {
+    miss.pat<-matrix(0,2,ncol(Y)+1)
+    n.patterns<-nrow(miss.pat)-1
+  }
+  
+  miss.pat.id<-rep(0,nrow(Y))
+  for (i in 1:nrow(Y)) {
+    k <- 1
+    flag <- 0
+    while ((k <= n.patterns) & (flag == 0)) {
+      if (all(!is.na(Y[i,])==miss.pat[k,1:(ncol(miss.pat))])) {
+        miss.pat.id[i] <- k
+        flag <- 1
+      } else {
+        k <- k + 1
+      }
+    }
+  }
+  
   for (i in 1:ncol(X)) {
     if (is.factor(X[,i])) X[,i]<-as.numeric(X[,i])
   }
@@ -40,9 +68,11 @@ jomo1rancon.MCMCchain<- function(Y, X=NULL, Z=NULL, clus, beta.start=NULL, u.sta
   Y<-data.matrix(Y)
   storage.mode(Y) <- "numeric"    
   X<-data.matrix(X)
-  storage.mode(X) <- "numeric"    
+  storage.mode(X) <- "numeric"  
+  stopifnot(!any(is.na(X)))
   Z<-data.matrix(Z)
-  storage.mode(Z) <- "numeric"    
+  storage.mode(Z) <- "numeric"  
+  stopifnot(!any(is.na(Z)))
   clus <- matrix(as.integer(levels(clus))[clus], ncol=1)
   if (output!=1) out.iter=nburn+2
   imp=matrix(0,nrow(Y)*(nimp+1),ncol(Y)+ncol(X)+ncol(Z)+3)
@@ -82,7 +112,7 @@ jomo1rancon.MCMCchain<- function(Y, X=NULL, Z=NULL, clus, beta.start=NULL, u.sta
   } 
   #for (i in 1:nrow(Y)) for (j in 1:ncol(Y)) if (is.na(Yimp[i,j])) Yimp[i,j]=rnorm(1,mean=meanobs[j], sd=0.01)
   Y.cat<-Y.numcat<-(-999)
-  .Call("jomo1ranC", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,betapost,upostall,covit,omegapost, covuit, covupost, nburn, l1cov.prior,l2cov.prior,Y.numcat, ncol(Y),out.iter, 1, PACKAGE = "jomo")
+  .Call("jomo1ranC", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,betapost,upostall,covit,omegapost, covuit, covupost, nburn, l1cov.prior,l2cov.prior,Y.numcat, ncol(Y),out.iter, 1, miss.pat.id, n.patterns, PACKAGE = "jomo")
   
   imp[(nrow(Y)+1):(2*nrow(Y)),1:ncol(Y)]=Yimp2
   imp<-data.frame(imp)
