@@ -54,11 +54,41 @@ function(Y.con, Y.cat, Y.numcat, X=NULL, Z=NULL, clus, beta.start=NULL, u.start=
   Y.cat<-data.matrix(Y.cat)
   storage.mode(Y.cat) <- "numeric"    
   X<-data.matrix(X)
-  storage.mode(X) <- "numeric"    
+  storage.mode(X) <- "numeric" 
+  stopifnot(!any(is.na(X)))
   Z<-data.matrix(Z)
-  storage.mode(Z) <- "numeric"    
+  storage.mode(Z) <- "numeric"
+  stopifnot(!any(is.na(Z)))
   clus <- matrix(as.integer(levels(clus))[clus], ncol=1)
   Y=cbind(Y.con,Y.cat)
+  if (any(is.na(Y))) {
+    if (ncol(Y)==1) {
+      miss.pat<-matrix(c(0,1),2,1)
+      n.patterns<-2
+    } else  {
+      miss.pat<-md.pattern.mice(Y, plot=F)
+      miss.pat<-miss.pat[,colnames(Y)]
+      n.patterns<-nrow(miss.pat)-1
+    }
+  } else {
+    miss.pat<-matrix(0,2,ncol(Y)+1)
+    n.patterns<-nrow(miss.pat)-1
+  }
+  
+  miss.pat.id<-rep(0,nrow(Y))
+  for (i in 1:nrow(Y)) {
+    k <- 1
+    flag <- 0
+    while ((k <= n.patterns) & (flag == 0)) {
+      if (all(!is.na(Y[i,])==miss.pat[k,1:(ncol(miss.pat))])) {
+        miss.pat.id[i] <- k
+        flag <- 1
+      } else {
+        k <- k + 1
+      }
+    }
+  }
+  
   Yi=cbind(Y.con, matrix(0,nrow(Y.con),(sum(Y.numcat)-length(Y.numcat))))
   h=1
   for (i in 1:length(Y.numcat)) {
@@ -93,7 +123,7 @@ function(Y.con, Y.cat, Y.numcat, X=NULL, Z=NULL, clus, beta.start=NULL, u.start=
   cpost<-matrix(0,nrow(l2cov.start),ncol(l2cov.start))
   meanobs<-colMeans(Yi,na.rm=TRUE)
   for (i in 1:nrow(Yi)) for (j in 1:ncol(Yi)) if (is.na(Yimp[i,j])) Yimp2[i,j]=rnorm(1,meanobs[j],1)
-  .Call("jomo1ranC", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,bpost,upost,covit,opost, covuit, cpost, nburn, l1cov.prior,l2cov.prior,Y.numcat, ncol(Y.con),out.iter,0, PACKAGE = "jomo")
+  .Call("jomo1ranC", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,bpost,upost,covit,opost, covuit, cpost, nburn, l1cov.prior,l2cov.prior,Y.numcat, ncol(Y.con),out.iter,0, miss.pat.id, n.patterns, PACKAGE = "jomo")
   #betapost[,,1]=bpost
   #upostall[,,1]=upost
   #omegapost[,,(1)]=opost
@@ -112,7 +142,7 @@ function(Y.con, Y.cat, Y.numcat, X=NULL, Z=NULL, clus, beta.start=NULL, u.start=
     imp[(i*nrow(clus)+1):((i+1)*nrow(clus)), (ncol(Y)+ncol(X)+ncol(Z)+1)]=clus
     imp[(i*nrow(Z)+1):((i+1)*nrow(Z)), (ncol(Y)+ncol(X)+ncol(Z)+2)]=c(1:nrow(Y))
     imp[(i*nrow(Z)+1):((i+1)*nrow(Z)), (ncol(Y)+ncol(X)+ncol(Z)+3)]=i 
-    .Call("jomo1ranC", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,bpost,upost,covit,opost, covuit, cpost, nbetween, l1cov.prior,l2cov.prior,Y.numcat, ncol(Y.con),out.iter,0, PACKAGE = "jomo")
+    .Call("jomo1ranC", Y, Yimp, Yimp2, Y.cat, X, Z, clus,betait,uit,bpost,upost,covit,opost, covuit, cpost, nbetween, l1cov.prior,l2cov.prior,Y.numcat, ncol(Y.con),out.iter,0, miss.pat.id, n.patterns, PACKAGE = "jomo")
     betapost[,,(i-1)]=bpost
     upostall[,,(i-1)]=upost
     omegapost[,,(i-1)]=opost
